.BG
.FN cfamily
.TL
Ridge Chaining Procedure
.DN
Chains the ridge estimates produced by the function {\tt crc}.
.CS
cfamily(ccridge, bstep=1, nbchain=100, ptile=0.05)
.RA
.OA
~move the above line to just above the first optional argument
.AG ccridge
unchained ridge set as the output of the function {\tt crc}
.AG bstep
maximal length for a gap in a ridge.
.AG nbchain
maximal number of chains produced by the function.
.AG ptile
relative threshold for the ridges.
.RT
Returns the results of the chaining algorithm
[ordered map:] image containing the ridges (displayed with
different colors)
[chain:] 2D array containing the chained ridges, according
to the chain data structure:
chain[,1]: first point of the ridge
chain[,2]: length of the chain
chain[,3:(chain[,2]+2)]: values of the ridge
[nbchain:] number of chains produced by the algorithm
.SE
~describe any side effects if they exist
.DT
{\tt crc} returns a measure in time-frequency (or time-scale)
space. {\tt cfamily} turns it into a series of one-dimensional
objects (ridges).

The measure is first thresholded, with a relative threshold value
set to the input parameter ptile.

During the chaining procedure, gaps
within a given ridge are allowed and filled in. The maximal length
of such gaps is the input parameter bstep.
.SH REFERENCES
.SA
{\tt crc} for the ridge estimation, and {\tt crcrec}, {\tt gcrcrec}
and {\tt scrcrec} for corresponding reconstruction functions.
.EX
# The function is currently defined as
function(ccridge, bstep = 1, nbchain = 100, ptile = 0.05)
{
#########################################################################
#     cfamily:
#     --------
#     chain the ridges obtained by crazy climber.
#
#      input:
#      ------
#       ccridge: unchained ridge (output of Bee_Annealing)
#       bstep: maximal length for a gap in a ridge
#       nbchain: maximum number of chains
#       ptile: relative threshold for the ridges 
#
#      output:
#      ------
#       ordered: ordered map: image containing the ridges
#                (displayed with different colors)
#       chain: 2D array containing the chained ridges, according
#		to the chain data structure:
#		chain[,1]: first point of the ridge
#		chain[,2]: length of the chain
#		chain[,3:(chain[,2]+2)]: values of the ridge
#	nbchain: number of chains.
#
#########################################################################
	d <- dim(ccridge)
	sigsize <- d[1]
	nscale <- d[2]
	threshold <- range(ccridge)[2] * ptile
	sz <- sigsize + 2
	chain <- matrix(-1, nbchain, sz)
	orderedmap <- matrix(0, sigsize, nscale)
	dim(chain) <- c(nbchain * sz, 1)
	dim(ccridge) <- c(nscale * sigsize, 1)
	dim(orderedmap) <- c(nscale * sigsize, 1)
	z <- .C("Scrazy_family",
		as.double(ccridge),
		orderedmap = as.single(orderedmap),
		chain = as.integer(chain),
		chainnb = as.integer(nbchain),
		as.integer(sigsize),
		as.integer(nscale),
		as.integer(bstep),
		as.single(threshold))
	orderedmap <- z$orderedmap
	chain <- z$chain
	dim(orderedmap) <- c(sigsize, nscale)
	dim(chain) <- c(nbchain, sz)
	nbchain <- z$chainnb
	chain <- chain + 1
	chain[, 2] <- chain[, 2] - 1
	list(ordered = orderedmap, chain = chain, nbchain = nbchain)
}
.KW ~keyword
.WR
